@@ -45,7 +45,7 @@ class Spectrum1D(OneDSpectrumMixin, NDCube, NDIOMixin, NDArithmeticMixin):
     wcs : `~astropy.wcs.WCS` or `~gwcs.wcs.WCS`
         WCS information object that either has a spectral component or is
         only spectral.
-    velocity_convention : {"doppler_relativistic", "doppler_optical", "doppler_radio"}
+    velocity_convention : {"relativistic", "optical", "radio"}
         Convention used for velocity conversions.
     rest_value : `~astropy.units.Quantity`
         Any quantity supported by the standard spectral equivalencies
@@ -323,9 +323,9 @@ class Spectrum1D(OneDSpectrumMixin, NDCube, NDIOMixin, NDArithmeticMixin):
         handled here.
         """
 
-        if self.flux.ndim > 1 or (type(item) == tuple and item[0] == Ellipsis):
-            if type(item) == tuple:
-                if len(item) == len(self.flux.shape) or item[0] == Ellipsis:
+        if self.flux.ndim > 1 or (isinstance(item, tuple) and item[0] is Ellipsis):
+            if isinstance(item, tuple):
+                if len(item) == len(self.flux.shape) or item[0] is Ellipsis:
                     spec_item = item[-1]
                     if not isinstance(spec_item, slice):
                         if isinstance(item, u.Quantity):
